GunChleoc has proposed merging
lp:~widelands-dev/widelands/bug-1620280-tabpanel-tooltip into lp:widelands.
Commit message:
Empty out TabPanel's tooltip when the mouse leaves the TabPanel.
Requested reviews:
Widelands Developers (widelands-dev)
Related bugs:
Bug #1620280 in widelands: "Silly little bug: wrong inventory tooltip"
https://bugs.launchpad.net/widelands/+bug/1620280
For more details, see:
https://code.launchpad.net/~widelands-dev/widelands/bug-1620280-tabpanel-tooltip/+merge/305208
--
Your team Widelands Developers is requested to review the proposed merge of
lp:~widelands-dev/widelands/bug-1620280-tabpanel-tooltip into lp:widelands.
=== modified file 'src/ui_basic/tabpanel.cc'
--- src/ui_basic/tabpanel.cc 2016-08-04 15:49:05 +0000
+++ src/ui_basic/tabpanel.cc 2016-09-08 12:11:49 +0000
@@ -347,11 +347,12 @@
}
/**
* Cancel all highlights when the mouse leaves the panel
*/
void TabPanel::handle_mousein(bool inside) {
if (!inside && highlight_ != kNotFound) {
highlight_ = kNotFound;
+ set_tooltip("");
}
}
_______________________________________________
@@ -347,11 +347,12 @@
}
/**
- * Cancel all highlights when the mouse leaves the panel
+ * Cancel all highlights and the tooltip when the mouse leaves the panel
*/
void TabPanel::handle_mousein(bool inside) {
Mailing list: https://launchpad.net/~widelands-dev
Post to : [email protected]
Unsubscribe : https://launchpad.net/~widelands-dev
More help : https://help.launchpad.net/ListHelp